@@ -23,7 +23,6 @@
 #include "dwg.h"
 #include "bits.h"
 
-EXPORT void
-dwg_free_eed(Dwg_Object* obj);
+EXPORT void dwg_free_eed (Dwg_Object *obj);
 
 #endif
